Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(353)

Unified Diff: talk/app/webrtc/webrtcsession.cc

Issue 1151943005: Ability to specify KeyType (RSA, ECDSA) for SSLIdentity generation in libjingle (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@master
Patch Set: Addressing ASAN, LSAN issues in unittests Created 5 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: talk/app/webrtc/webrtcsession.cc
diff --git a/talk/app/webrtc/webrtcsession.cc b/talk/app/webrtc/webrtcsession.cc
index 5c8b2df754fe8d69dd5928e2a0477e3f2e8e50ab..d55b7109eaa5f57e68d6ee5c026c810129da8198 100644
--- a/talk/app/webrtc/webrtcsession.cc
+++ b/talk/app/webrtc/webrtcsession.cc
@@ -520,8 +520,9 @@ WebRtcSession::~WebRtcSession() {
bool WebRtcSession::Initialize(
const PeerConnectionFactoryInterface::Options& options,
const MediaConstraintsInterface* constraints,
- DTLSIdentityServiceInterface* dtls_identity_service,
- const PeerConnectionInterface::RTCConfiguration& rtc_configuration) {
+ const PeerConnectionInterface::RTCConfiguration& rtc_configuration,
+ DtlsIdentityStoreInterface* dtls_identity_store,
+ rtc::KeyType key_type) {
bundle_policy_ = rtc_configuration.bundle_policy;
rtcp_mux_policy_ = rtc_configuration.rtcp_mux_policy;
SetSslMaxProtocolVersion(options.ssl_max_version);
@@ -534,8 +535,8 @@ bool WebRtcSession::Initialize(
if (options.disable_encryption) {
dtls_enabled_ = false;
} else {
- // Enable DTLS by default if |dtls_identity_service| is valid.
- dtls_enabled_ = (dtls_identity_service != NULL);
+ // Enable DTLS by default if we have a |dtls_identity_store|.
+ dtls_enabled_ = (dtls_identity_store != nullptr);
// |constraints| can override the default |dtls_enabled_| value.
if (FindConstraint(
constraints,
@@ -661,11 +662,12 @@ bool WebRtcSession::Initialize(
signaling_thread(),
channel_manager_,
mediastream_signaling_,
- dtls_identity_service,
+ dtls_identity_store,
this,
id(),
data_channel_type_,
- dtls_enabled_));
+ dtls_enabled_,
+ key_type));
webrtc_session_desc_factory_->SignalIdentityReady.connect(
this, &WebRtcSession::OnIdentityReady);

Powered by Google App Engine
This is Rietveld 408576698